@@ -1,6 +1,5 @@
 import re
-from debian_linux.debian import Version, PackageFieldList
-from debian_linux.debian import PackageFieldList as _PackageFieldList
+from debian_linux.debian import Version
 
 
 class VersionXen(Version):
@@ -29,8 +28,3 @@ $
         d = match.groupdict()
         self.xen_version = d['version']
 
-
-class PackageFieldList(_PackageFieldList):
-    def __init__(self, value=None):
-        if value:
-            super(self, PackageFieldList).__init__(value)
